@@ -2,10 +2,6 @@ require 'spec_helper'
 
 describe 'xinetd::service' do
 
-  let :facts do
-    { :osfamily => 'Debian' }
-  end
-
   let :default_params do
     {
       'port'   => '80',
@@ -17,6 +13,25 @@ describe 'xinetd::service' do
     "httpd"
   end
 
+  describe "ensure proper user/group are set in FreeBSD" do
+    let :facts do
+      { :osfamily => 'FreeBSD' }
+    end
+
+    let :params do
+      default_params
+    end
+
+    it {
+      should contain_file('/usr/local/etc/xinetd.d/httpd').with_content(/user\s*=\sroot/)
+      should contain_file('/usr/local/etc/xinetd.d/httpd').with_content(/group\s*=\swheel/)
+    }
+  end
+
+  let :facts do
+    { :osfamily => 'Debian' }
+  end
+
   describe 'with default ensure' do
     let :params do
       default_params
@@ -44,6 +59,33 @@ describe 'xinetd::service' do
     }
   end
 
+  describe 'with group' do
+    let :params do
+      default_params.merge({'group' => 'foo'})
+    end
+    it {
+      should contain_file('/etc/xinetd.d/httpd').with_content(/group\s*=\s*foo/)
+    }
+  end
+
+  describe 'with use_default_group true' do
+    let :params do
+      default_params.merge({'use_default_group' => true})
+    end
+    it {
+      should contain_file('/etc/xinetd.d/httpd').with_content(/group\s*=\s*root/)
+    }
+  end
+
+  describe 'with use_default_group false' do
+    let :params do
+      default_params.merge({'use_default_group' => false})
+    end
+    it {
+      should contain_file('/etc/xinetd.d/httpd').without_content(/group\s*=/)
+    }
+  end
+
   describe 'without log_on_<success|failure>' do
     let :params do
       default_params
@@ -87,24 +129,54 @@ describe 'xinetd::service' do
   end
 
   # nice values, good
-  ['-19','9','19'].each do |i|
-    describe "with nice #{i}" do
+  [-20,0,9,19].each do |i|
+    describe "with nice valid nice value: #{i}" do
       let :params do
         default_params.merge({ :nice => i })
       end
-      it {
-        should contain_file('/etc/xinetd.d/httpd').with_content(
-          /nice\s*=\s*#{i}/)
-      }
+
+      it { should contain_file('/etc/xinetd.d/httpd').with_content(/nice\s*=\s*#{i}/) }
     end
   end
+
   # nice values, bad
-  ['-20','90','foo'].each do |i|
-    describe "with nice #{i}" do
+  ['-21','90','foo',-21,90,20].each do |i|
+    describe "with out-of-range nice value: #{i}" do
       let :params do
         default_params.merge({ :nice => i })
       end
-      it { expect { should compile }.to raise_error(Puppet::Error) }
+
+      it 'should fail' do
+        expect {
+          should contain_class('xinetd')
+        }.to raise_error(Puppet::Error)
+      end
+    end
+  end
+
+  describe 'with redirect' do
+    let :params do
+      {
+        :port     => '80',
+        :redirect => 'somehost.somewhere 65535',
+      }
+    end
+    it {
+      should contain_file('/etc/xinetd.d/httpd').with_content(
+        /redirect\s*\=\s*somehost.somewhere 65535/)
+    }
+  end
+
+  describe 'without redirect and server' do
+    let :params do
+      {
+        :port => '80',
+      }
+    end
+    it 'should fail' do
+      expect {
+        should contain_class('xinetd')
+      }.to raise_error(Puppet::Error)
     end
   end
 end
